function [tau_avg_vec] = compute_shear_flow(x_profile,y_profile,eta_0_Cross,tau_0_Cross,n_Cross,tau_cr,V_vec)
% Shear flow of matrix in ply-ply interface
%   Run certain height profile with 1D shear rate approach to determine
%   average shear stress for each sliding velocity in vector

% Version: 11-7-2022
% Matlab version: R2021a

% Cross model viscosity
eta_func = @(V,h) ((eta_0_Cross)./(1+(eta_0_Cross.*(V./h)./tau_0_Cross).^(1-n_Cross)));

% go through range of sliding velocities 
tau_avg_vec = []; % store average shear stress per rate

for j = 1:length(V_vec)
    V_sliding = V_vec(j);
    tau_dx = 0;
    nr_steps = 0;

    % go through profile
    for i = 1:length(x_profile)-1
        dx = x_profile(i+1)-x_profile(i); % width of small segment; used for weighting
        dy = 0.5*(y_profile(i)+y_profile(i+1)); % height of small segment
        if dy == 0
            tau_i = 0;
        else
            tau_i = eta_func(V_sliding,dy)*(V_sliding/dy); % local viscous shear stress
            if tau_cr ~= 0  % apply slip effect
                tau_i = min(tau_cr,tau_i); % local viscous shear stress, limited through critical shear stress
            end    
        end
        tau_dx = tau_dx + tau_i*dx; % cumulative shear stress small segment times width (weighting)
    end
    tau_avg = tau_dx/(x_profile(end)-x_profile(1)); % average shear stress over width of ply-ply interface
    tau_avg_vec = [tau_avg_vec, tau_avg]; % store average shear stress per rate, in Pa
end
end

